@@ -1,6 +1,6 @@
 package Net::DNS::RR::MX;
 
-# $Id: MX.pm,v 1.3 1997/06/13 03:33:54 mfuhr Exp $
+# $Id: MX.pm,v 1.4 1997/07/06 16:31:54 mfuhr Exp $
 
 use strict;
 use vars qw(@ISA);
@@ -25,6 +25,18 @@ sub new {
 	return bless $self, $class;
 }
 
+sub new_from_string {
+	my ($class, $self, $string) = @_;
+
+	if ($string && ($string =~ /^(\d+)\s+(\S+)$/)) {
+		$self->{"preference"} = $1;
+		$self->{"exchange"}   = $2;
+		$self->{"exchange"}   =~ s/\.+$//;;
+	}
+
+	return bless $self, $class;
+}
+
 sub rdatastr {
 	my $self = shift;
 
